EventBroker.Event
(event_broker v1.1.1)
I am an Event module for the Event Broker.
I provide the standard event format to be distributed for the PubSub system. Unless the message is in my format it does not get processed.