EventBroker.Filter behaviour (event_broker v1.1.1)

I am a filter module for the Event Broker. I provide the callbacks for all the filters used in the PubSub system.

Summary

Callbacks

filter(t, struct)

@callback filter(
  EventBroker.Event.t(),
  struct()
) :: bool()