Examples.EEventBroker.EFilter
(event_broker v1.1.1)
I define examples on how to use the deffilter macro to create filters for the event broker.
I define examples on how to use the deffilter macro to create filters for the event broker.